#
# spec file for package gq
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gq
BuildRequires:  glib2-devel
BuildRequires:  gnome-common
BuildRequires:  gtk2-devel
BuildRequires:  krb5-devel
BuildRequires:  libglade2-devel
%if 0%{?suse_version} >= 1130
BuildRequires:  libgnome-keyring-devel
%else
BuildRequires:  gnome-keyring-devel
%endif
BuildRequires:  libgcrypt-devel
BuildRequires:  libxml2-devel
BuildRequires:  openldap2-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
Summary:        An LDAP Client for GTK
License:        GPL-2.0-or-later
Group:          Productivity/Networking/LDAP/Clients
Version:        1.2.3
Release:        93.3
URL:            http://gq-project.org/
Source0:        gq-%{version}.tar.bz2
Source1:        gq-%{version}-langpack-1.tar.bz2
# PATCH-FIX-UPSTREAM gq-fix-linking.patch vuntz@opensuse.org -- Fix linking issue, taken from git
Patch0:         gq-fix-linking.patch
# PATCH-FIX-UPSTREAM gq-glib-2.31.patch dimstar@opensuse.org -- Fix build with glib 2.31. Sent upstream by mail (vuntz, 2011-01-05)
Patch1:         gq-glib-2.31.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
An LDAP client for GTK.

%prep
%setup -q
%autosetup -T -D -a 1 -p1

%build
# needed for patch0
autoreconf -fi -I macros
gq-%{version}-langpack-1/langpack .
export CFLAGS="-DLDAP_DEPRECATED $RPM_OPT_FLAGS -fcommon"
%configure \
    --enable-browser-dnd 		\
    --disable-update-mimedb             \
    --disable-debugging
%__make %{?jobs:-j%jobs}

%install
%makeinstall
%suse_update_desktop_file %name System ServiceConfiguration

%clean
rm -rf $RPM_BUILD_ROOT

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%mime_database_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%mime_database_postun
%endif

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_bindir}/gq
%{_datadir}/pixmaps/gq/
#%{prefix}/share/locale/*/LC_MESSAGES/gq.mo
%{_datadir}/applications/gq.desktop
%{_datadir}/gq
%{_datadir}/mime/packages/gq-ldif.xml

%changelog
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Export -fcommon to optflags, fixes build with gcc 10. Yes this is
  a cheat, but good enough for this more or less abandoned package.
* Wed Nov 30 2011 dimstar@opensuse.org
- Add gq-glib-2.31.patch: Fix build with glib 2.31.
* Mon Sep  5 2011 vuntz@opensuse.org
- Add libgcrypt-devel BuildRequires: it has been forgotten for some
  reason.
- Drop gq-1.2.3-ia64.diff: the patch never made it upstream, and is
  actually only useful if we turn on debugging. Instead, pass
  - -disable-debugging to configure.
- Add gq-fix-linking.patch: fix linking issue, taken from git.
- Add call to autoreconf for above patch.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel on 11.3 and later, following the module
  split upstream.
- Remove AutoReqProv: it's default now.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Aug  5 2009 dominique-obs@leuenberger.net
- Remove --with-kerberos-prefix from configure. Newest krb5
  packages do no longer provide the expected libdes425.
* Fri Mar 21 2008 jpr@suse.de
- Resurrect gq (bnc #9512)
